import redis from 'redis';
import util from 'util';
import consola from 'consola/dist/consola';
import config from '../config';

// 创建redis连接
const client = redis.createClient({
  host: config.redis.host,
  port: config.redis.port,
  password: config.redis.password,
  auth_pass: config.redis.password
});

client.on('error', err => {
  consola.error(err);
});
client.on('ready', () => {
  consola.success('redis is ready');
});
client.on('connect', () => {
  consola.success('redis is connecting');
});
client.on('reconnecting', () => {
  consola.success('redis is reconnecting...');
});
client.on('end', () => {
  consola.success('redis is closed');
});
client.on('end', () => {
  consola.success('redis is closed');
});

// redis查询和设置await/async化
const promisify = util.promisify
const getClient = promisify(client.get).bind(client);
const setClient = promisify(client.set).bind(client);
const setexClient = promisify(client.setex).bind(client);

// 初始化测试
client.setex('test', 30, '111111');
// send_sms_verify_code_sms_
// 18339012129

export = () => {
  return async (ctx, next) => {
    ctx.$redis = { set: setClient, get: getClient, setex: setexClient };
    await next();
  };
};
